==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/ServiceAccountPodSecurityPolicyReviewStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.PodTemplateSpecFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ServiceAccountPodSecurityPolicyReviewStatusFluentImpl<A extends io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent<A>{
  public ServiceAccountPodSecurityPolicyReviewStatusFluentImpl() {
  }
  public ServiceAccountPodSecurityPolicyReviewStatusFluentImpl(io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus instance) {
    this.withAllowedBy(instance.getAllowedBy()); 
    this.withName(instance.getName()); 
    this.withReason(instance.getReason()); 
    this.withTemplate(instance.getTemplate()); 
  }
  private io.fabric8.kubernetes.api.model.ObjectReferenceBuilder allowedBy;
  private java.lang.String name;
  private java.lang.String reason;
  private io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder template;
  
  /**
   * This method has been deprecated, please use method buildAllowedBy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getAllowedBy() {
    return this.allowedBy!=null?this.allowedBy.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectReference buildAllowedBy() {
    return this.allowedBy!=null?this.allowedBy.build():null;
  }
  public A withAllowedBy(io.fabric8.kubernetes.api.model.ObjectReference allowedBy) {
    _visitables.get("allowedBy").remove(this.allowedBy);
    if (allowedBy!=null){ this.allowedBy= new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(allowedBy); _visitables.get("allowedBy").add(this.allowedBy);} return (A) this;
  }
  public java.lang.Boolean hasAllowedBy() {
    return this.allowedBy != null;
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.AllowedByNested<A> withNewAllowedBy() {
    return new io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluentImpl.AllowedByNestedImpl();
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.AllowedByNested<A> withNewAllowedByLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return new io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluentImpl.AllowedByNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.AllowedByNested<A> editAllowedBy() {
    return withNewAllowedByLike(getAllowedBy());
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.AllowedByNested<A> editOrNewAllowedBy() {
    return withNewAllowedByLike(getAllowedBy() != null ? getAllowedBy(): new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.AllowedByNested<A> editOrNewAllowedByLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return withNewAllowedByLike(getAllowedBy() != null ? getAllowedBy(): item);
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getReason() {
    return this.reason;
  }
  public A withReason(java.lang.String reason) {
    this.reason=reason; return (A) this;
  }
  public java.lang.Boolean hasReason() {
    return this.reason != null;
  }
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0) {
    return (A)withReason(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.PodTemplateSpec getTemplate() {
    return this.template!=null?this.template.build():null;
  }
  public io.fabric8.kubernetes.api.model.PodTemplateSpec buildTemplate() {
    return this.template!=null?this.template.build():null;
  }
  public A withTemplate(io.fabric8.kubernetes.api.model.PodTemplateSpec template) {
    _visitables.get("template").remove(this.template);
    if (template!=null){ this.template= new io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder(template); _visitables.get("template").add(this.template);} return (A) this;
  }
  public java.lang.Boolean hasTemplate() {
    return this.template != null;
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.TemplateNested<A> withNewTemplate() {
    return new io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluentImpl.TemplateNestedImpl();
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.TemplateNested<A> withNewTemplateLike(io.fabric8.kubernetes.api.model.PodTemplateSpec item) {
    return new io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluentImpl.TemplateNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.TemplateNested<A> editTemplate() {
    return withNewTemplateLike(getTemplate());
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.TemplateNested<A> editOrNewTemplate() {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): new io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder().build());
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.TemplateNested<A> editOrNewTemplateLike(io.fabric8.kubernetes.api.model.PodTemplateSpec item) {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ServiceAccountPodSecurityPolicyReviewStatusFluentImpl that = (ServiceAccountPodSecurityPolicyReviewStatusFluentImpl) o;
    if (allowedBy != null ? !allowedBy.equals(that.allowedBy) :that.allowedBy != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
    if (template != null ? !template.equals(that.template) :that.template != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowedBy,  name,  reason,  template,  super.hashCode());
  }
  public class AllowedByNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.AllowedByNested<N>> implements io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.AllowedByNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AllowedByNestedImpl(io.fabric8.kubernetes.api.model.ObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this, item);
    }
    AllowedByNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectReferenceBuilder builder;
    public N and() {
      return (N) ServiceAccountPodSecurityPolicyReviewStatusFluentImpl.this.withAllowedBy(builder.build());
    }
    public N endAllowedBy() {
      return and();
    }
    
  }
  public class TemplateNestedImpl<N> extends io.fabric8.kubernetes.api.model.PodTemplateSpecFluentImpl<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.TemplateNested<N>> implements io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.TemplateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TemplateNestedImpl(io.fabric8.kubernetes.api.model.PodTemplateSpec item) {
      this.builder = new io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder(this, item);
    }
    TemplateNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder(this);
    }
    io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder builder;
    public N and() {
      return (N) ServiceAccountPodSecurityPolicyReviewStatusFluentImpl.this.withTemplate(builder.build());
    }
    public N endTemplate() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/ServiceAccountPodSecurityPolicyReviewStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.PodTemplateSpecFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ServiceAccountPodSecurityPolicyReviewStatusFluentImpl<A extends io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent<A>{
  public ServiceAccountPodSecurityPolicyReviewStatusFluentImpl() {
  }
  public ServiceAccountPodSecurityPolicyReviewStatusFluentImpl(io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatus instance) {
    this.withAllowedBy(instance.getAllowedBy()); 
    this.withName(instance.getName()); 
    this.withReason(instance.getReason()); 
    this.withTemplate(instance.getTemplate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.ObjectReferenceBuilder allowedBy;
  private java.lang.String name;
  private java.lang.String reason;
  private io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder template;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAllowedBy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getAllowedBy() {
    return this.allowedBy!=null?this.allowedBy.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectReference buildAllowedBy() {
    return this.allowedBy!=null?this.allowedBy.build():null;
  }
  public A withAllowedBy(io.fabric8.kubernetes.api.model.ObjectReference allowedBy) {
    _visitables.get("allowedBy").remove(this.allowedBy);
    if (allowedBy!=null){ this.allowedBy= new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(allowedBy); _visitables.get("allowedBy").add(this.allowedBy);} return (A) this;
  }
  public java.lang.Boolean hasAllowedBy() {
    return this.allowedBy != null;
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.AllowedByNested<A> withNewAllowedBy() {
    return new io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluentImpl.AllowedByNestedImpl();
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.AllowedByNested<A> withNewAllowedByLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return new io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluentImpl.AllowedByNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.AllowedByNested<A> editAllowedBy() {
    return withNewAllowedByLike(getAllowedBy());
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.AllowedByNested<A> editOrNewAllowedBy() {
    return withNewAllowedByLike(getAllowedBy() != null ? getAllowedBy(): new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.AllowedByNested<A> editOrNewAllowedByLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return withNewAllowedByLike(getAllowedBy() != null ? getAllowedBy(): item);
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getReason() {
    return this.reason;
  }
  public A withReason(java.lang.String reason) {
    this.reason=reason; return (A) this;
  }
  public java.lang.Boolean hasReason() {
    return this.reason != null;
  }
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0) {
    return (A)withReason(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.PodTemplateSpec getTemplate() {
    return this.template!=null?this.template.build():null;
  }
  public io.fabric8.kubernetes.api.model.PodTemplateSpec buildTemplate() {
    return this.template!=null?this.template.build():null;
  }
  public A withTemplate(io.fabric8.kubernetes.api.model.PodTemplateSpec template) {
    _visitables.get("template").remove(this.template);
    if (template!=null){ this.template= new io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder(template); _visitables.get("template").add(this.template);} return (A) this;
  }
  public java.lang.Boolean hasTemplate() {
    return this.template != null;
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.TemplateNested<A> withNewTemplate() {
    return new io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluentImpl.TemplateNestedImpl();
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.TemplateNested<A> withNewTemplateLike(io.fabric8.kubernetes.api.model.PodTemplateSpec item) {
    return new io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluentImpl.TemplateNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.TemplateNested<A> editTemplate() {
    return withNewTemplateLike(getTemplate());
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.TemplateNested<A> editOrNewTemplate() {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): new io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder().build());
  }
  public io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.TemplateNested<A> editOrNewTemplateLike(io.fabric8.kubernetes.api.model.PodTemplateSpec item) {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ServiceAccountPodSecurityPolicyReviewStatusFluentImpl that = (ServiceAccountPodSecurityPolicyReviewStatusFluentImpl) o;
    if (allowedBy != null ? !allowedBy.equals(that.allowedBy) :that.allowedBy != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
    if (template != null ? !template.equals(that.template) :that.template != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowedBy,  name,  reason,  template,  additionalProperties,  super.hashCode());
  }
  public class AllowedByNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.AllowedByNested<N>> implements io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.AllowedByNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AllowedByNestedImpl(io.fabric8.kubernetes.api.model.ObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this, item);
    }
    AllowedByNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectReferenceBuilder builder;
    public N and() {
      return (N) ServiceAccountPodSecurityPolicyReviewStatusFluentImpl.this.withAllowedBy(builder.build());
    }
    public N endAllowedBy() {
      return and();
    }
    
  }
  public class TemplateNestedImpl<N> extends io.fabric8.kubernetes.api.model.PodTemplateSpecFluentImpl<io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.TemplateNested<N>> implements io.fabric8.openshift.api.model.ServiceAccountPodSecurityPolicyReviewStatusFluent.TemplateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TemplateNestedImpl(io.fabric8.kubernetes.api.model.PodTemplateSpec item) {
      this.builder = new io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder(this, item);
    }
    TemplateNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder(this);
    }
    io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder builder;
    public N and() {
      return (N) ServiceAccountPodSecurityPolicyReviewStatusFluentImpl.this.withTemplate(builder.build());
    }
    public N endTemplate() {
      return and();
    }
    
  }
  
}
